+{
   entry => <<'ENTRY', # for DUCET v5.2.0
1EB9      ; [.126C.0020.0002.1EB9] # LATIN SMALL LETTER E WITH DOT BELOW
0065 0323 ; [.126C.0020.0002.1EB9] # LATIN SMALL LETTER E WITH DOT BELOW
1EB8      ; [.126C.0020.0008.1EB8] # LATIN CAPITAL LETTER E WITH DOT BELOW
0045 0323 ; [.126C.0020.0008.1EB8] # LATIN CAPITAL LETTER E WITH DOT BELOW
0067 0062 ; [.12B1.0020.0002.0067] # <LATIN SMALL LETTER G, LATIN SMALL LETTER B>
0047 0062 ; [.12B1.0020.0007.0047] # <LATIN CAPITAL LETTER G, LATIN SMALL LETTER B>
0047 0042 ; [.12B1.0020.0008.0047] # <LATIN CAPITAL LETTER G, LATIN CAPITAL LETTER B>
1ECD      ; [.138F.0020.0002.1ECD] # LATIN SMALL LETTER O WITH DOT BELOW
006F 0323 ; [.138F.0020.0002.1ECD] # LATIN SMALL LETTER O WITH DOT BELOW
1ECC      ; [.138F.0020.0008.1ECC] # LATIN CAPITAL LETTER O WITH DOT BELOW
004F 0323 ; [.138F.0020.0008.1ECC] # LATIN CAPITAL LETTER O WITH DOT BELOW
1E63      ; [.1411.0020.0002.1E63] # LATIN SMALL LETTER S WITH DOT BELOW
0073 0323 ; [.1411.0020.0002.1E63] # LATIN SMALL LETTER S WITH DOT BELOW
1E62      ; [.1411.0020.0008.1E62] # LATIN CAPITAL LETTER S WITH DOT BELOW
0053 0323 ; [.1411.0020.0008.1E62] # LATIN CAPITAL LETTER S WITH DOT BELOW
ENTRY
};
