+{
   entry => <<'ENTRY', # for DUCET v5.2.0
0103      ; [.1210.0020.0002.0103] # LATIN SMALL LETTER A WITH BREVE
0061 0306 ; [.1210.0020.0002.0103] # LATIN SMALL LETTER A WITH BREVE
0102      ; [.1210.0020.0008.0102] # LATIN CAPITAL LETTER A WITH BREVE
0041 0306 ; [.1210.0020.0008.0102] # LATIN CAPITAL LETTER A WITH BREVE
00E2      ; [.1211.0020.0002.00E2] # LATIN SMALL LETTER A WITH CIRCUMFLEX
0061 0302 ; [.1211.0020.0002.00E2] # LATIN SMALL LETTER A WITH CIRCUMFLEX
00C2      ; [.1211.0020.0008.00C2] # LATIN CAPITAL LETTER A WITH CIRCUMFLEX
0041 0302 ; [.1211.0020.0008.00C2] # LATIN CAPITAL LETTER A WITH CIRCUMFLEX
0111      ; [.1251.0020.0002.0111] # LATIN SMALL LETTER D WITH STROKE
0064 0335 ; [.1251.0020.0002.0111] # LATIN SMALL LETTER D WITH STROKE
0110      ; [.1251.0020.0008.0110] # LATIN CAPITAL LETTER D WITH STROKE
0044 0335 ; [.1251.0020.0008.0110] # LATIN CAPITAL LETTER D WITH STROKE
00EE      ; [.12ED.0020.0002.00EE] # LATIN SMALL LETTER I WITH CIRCUMFLEX
0069 0302 ; [.12ED.0020.0002.00EE] # LATIN SMALL LETTER I WITH CIRCUMFLEX
00CE      ; [.12ED.0020.0008.00CE] # LATIN CAPITAL LETTER I WITH CIRCUMFLEX
0049 0302 ; [.12ED.0020.0008.00CE] # LATIN CAPITAL LETTER I WITH CIRCUMFLEX
015F      ; [.1411.0020.0002.015F] # LATIN SMALL LETTER S WITH CEDILLA
0073 0327 ; [.1411.0020.0002.015F] # LATIN SMALL LETTER S WITH CEDILLA
0219      ; [.1411.0020.0002.0219] # LATIN SMALL LETTER S WITH COMMA BELOW
0073 0326 ; [.1411.0020.0002.0219] # LATIN SMALL LETTER S WITH COMMA BELOW
015E      ; [.1411.0020.0008.015E] # LATIN CAPITAL LETTER S WITH CEDILLA
0053 0327 ; [.1411.0020.0008.015E] # LATIN CAPITAL LETTER S WITH CEDILLA
0218      ; [.1411.0020.0008.0218] # LATIN CAPITAL LETTER S WITH COMMA BELOW
0053 0326 ; [.1411.0020.0008.0218] # LATIN CAPITAL LETTER S WITH COMMA BELOW
0163      ; [.1434.0020.0002.0163] # LATIN SMALL LETTER T WITH CEDILLA
0074 0327 ; [.1434.0020.0002.0163] # LATIN SMALL LETTER T WITH CEDILLA
021B      ; [.1434.0020.0002.021B] # LATIN SMALL LETTER T WITH COMMA BELOW
0074 0326 ; [.1434.0020.0002.021B] # LATIN SMALL LETTER T WITH COMMA BELOW
0162      ; [.1434.0020.0008.0162] # LATIN CAPITAL LETTER T WITH CEDILLA
0054 0327 ; [.1434.0020.0008.0162] # LATIN CAPITAL LETTER T WITH CEDILLA
021A      ; [.1434.0020.0008.021A] # LATIN CAPITAL LETTER T WITH COMMA BELOW
0054 0326 ; [.1434.0020.0008.021A] # LATIN CAPITAL LETTER T WITH COMMA BELOW
017C      ; [.14AE.0020.0002.017C] # LATIN SMALL LETTER Z WITH DOT ABOVE
007A 0307 ; [.14AE.0020.0002.017C] # LATIN SMALL LETTER Z WITH DOT ABOVE
017B      ; [.14AE.0020.0008.017B] # LATIN CAPITAL LETTER Z WITH DOT ABOVE
005A 0307 ; [.14AE.0020.0008.017B] # LATIN CAPITAL LETTER Z WITH DOT ABOVE
ENTRY
};
